@@ -14,15 +14,13 @@ __author__ = (
     "Mark Harviston <mark.harviston@gmail.com>, "
     "Arve Knudsen <arve.knudsen@gmail.com>",
 )
-__version__ = "0.21.0"
-__url__ = "https://github.com/CabbageDevelopment/qasync"
-__license__ = "BSD"
 __all__ = ["QEventLoop", "QThreadExecutor", "asyncSlot", "asyncClose"]
 
 import asyncio
 import contextlib
 import functools
 import importlib
+import inspect
 import itertools
 import logging
 import os
@@ -79,8 +77,6 @@ if not QtModule:
 if not QtModule:
     raise ImportError("No Qt implementations found")
 
-logger.info("Using Qt Implementation: {}".format(QtModuleName))
-
 QtCore = importlib.import_module(QtModuleName + ".QtCore", package=QtModuleName)
 QtGui = importlib.import_module(QtModuleName + ".QtGui", package=QtModuleName)
 
@@ -184,11 +180,11 @@ class QThreadExecutor:
         if stack_size is None:
             # Match cpython/Python/thread_pthread.h
             if sys.platform.startswith("darwin"):
-                stack_size = 16 * 2 ** 20
+                stack_size = 16 * 2**20
             elif sys.platform.startswith("freebsd"):
-                stack_size = 4 * 2 ** 20
+                stack_size = 4 * 2**20
             elif sys.platform.startswith("aix"):
-                stack_size = 2 * 2 ** 20
+                stack_size = 2 * 2**20
         self.__workers = [
             _QThreadWorker(self.__queue, i + 1, stack_size) for i in range(max_workers)
         ]
@@ -256,7 +252,7 @@ class _SimpleTimer(QtCore.QObject):
         self.__debug_enabled = False
 
     def add_callback(self, handle, delay=0):
-        timerid = self.startTimer(int(delay * 1000))
+        timerid = self.startTimer(int(max(0, delay) * 1000))
         self.__log_debug("Registering timer id %s", timerid)
         assert timerid not in self.__callbacks
         self.__callbacks[timerid] = handle
@@ -329,9 +325,11 @@ class _QEventLoop:
     If the event loop shall be used with an existing and already running QApplication
     it must be specified in the constructor via already_running=True
     In this case the user is responsible for loop cleanup with stop() and close()
+
+    The set_running_loop parameter is there for backwards compatibility and does nothing.
     """
 
-    def __init__(self, app=None, set_running_loop=True, already_running=False):
+    def __init__(self, app=None, set_running_loop=False, already_running=False):
         self.__app = app or QApplication.instance()
         assert self.__app is not None, "No QApplication has been instantiated"
         self.__is_running = False
@@ -349,9 +347,6 @@ class _QEventLoop:
         assert self.__app is not None
         super().__init__()
 
-        if set_running_loop:
-            asyncio.events._set_running_loop(self)
-
         # We have to set __is_running to True after calling
         # super().__init__() because of a bug in BaseEventLoop.
         if already_running:
@@ -362,6 +357,9 @@ class _QEventLoop:
             self._before_run_forever()
             self.__app.aboutToQuit.connect(self._after_run_forever)
 
+            # for asyncio to recognize the already running loop
+            asyncio.events._set_running_loop(self)
+
     def run_forever(self):
         """Run eventloop forever."""
 
@@ -373,14 +371,16 @@ class _QEventLoop:
 
         try:
             self.__log_debug("Starting Qt event loop")
+            asyncio.events._set_running_loop(self)
             rslt = -1
-            try:
-                rslt = self.__app.exec_()
-            except AttributeError:
+            if hasattr(self.__app, "exec"):
                 rslt = self.__app.exec()
+            else:
+                rslt = self.__app.exec_()
             self.__log_debug("Qt event loop ended with result %s", rslt)
             return rslt
         finally:
+            asyncio.events._set_running_loop(None)
             self._after_run_forever()
             self.__is_running = False
 
@@ -539,7 +539,10 @@ class _QEventLoop:
             existing.activated["int"].disconnect()
             # will get overwritten by the assignment below anyways
 
-        notifier = QtCore.QSocketNotifier(fd, QtCore.QSocketNotifier.Type.Write)
+        notifier = QtCore.QSocketNotifier(
+            _fileno(fd),
+            QtCore.QSocketNotifier.Type.Write,
+        )
         notifier.setEnabled(True)
         self.__log_debug("Adding writer callback for file descriptor %s", fd)
         notifier.activated["int"].connect(
@@ -769,7 +772,7 @@ def asyncClose(fn):
     return wrapper
 
 
-def asyncSlot(*args):
+def asyncSlot(*args, **kwargs):
     """Make a Qt async slot run on asyncio loop."""
 
     def _error_handler(task):
@@ -779,11 +782,30 @@ def asyncSlot(*args):
             sys.excepthook(*sys.exc_info())
 
     def outer_decorator(fn):
-        @Slot(*args)
+        @Slot(*args, **kwargs)
         @functools.wraps(fn)
         def wrapper(*args, **kwargs):
-            task = asyncio.ensure_future(fn(*args, **kwargs))
-            task.add_done_callback(_error_handler)
+            # Qt ignores trailing args from a signal but python does
+            # not so inspect the slot signature and if it's not
+            # callable try removing args until it is.
+            task = None
+            while len(args):
+                try:
+                    inspect.signature(fn).bind(*args, **kwargs)
+                except TypeError:
+                    if len(args):
+                        # Only convert args to a list if we need to pop()
+                        args = list(args)
+                        args.pop()
+                        continue
+                else:
+                    task = asyncio.ensure_future(fn(*args, **kwargs))
+                    task.add_done_callback(_error_handler)
+                    break
+            if task is None:
+                raise TypeError(
+                    "asyncSlot was not callable from Signal. Potential signature mismatch."
+                )
             return task
 
         return wrapper
@@ -793,7 +815,7 @@ def asyncSlot(*args):
 
 class QEventLoopPolicyMixin:
     def new_event_loop(self):
-        return QEventLoop(QApplication(sys.argv))
+        return QEventLoop(QApplication.instance() or QApplication(sys.argv))
 
 
 class DefaultQEventLoopPolicy(
