@@ -151,6 +151,8 @@ def test_can_read_subprocess(loop):
             'print("Hello async world!")',
             stdout=subprocess.PIPE,
         )
+        if process.stdout is None:
+            raise Exception("Output from the process is none")
         received_stdout = await process.stdout.readexactly(len(b"Hello async world!\n"))
         await process.wait()
         assert process.returncode == 0
@@ -589,8 +591,8 @@ def test_regression_bug13(loop, sock_pair):
 
         loop._add_reader(c_sock.fileno(), cb1)
 
-    asyncio.ensure_future(client_coro())
-    asyncio.ensure_future(server_coro())
+    _client_task = asyncio.ensure_future(client_coro())
+    _server_task = asyncio.ensure_future(server_coro())
 
     both_done = asyncio.gather(client_done, server_done)
     loop.run_until_complete(asyncio.wait_for(both_done, timeout=1.0))
@@ -786,3 +788,16 @@ def test_not_running_immediately_after_stopped(loop):
     assert not loop.is_running()
     loop.run_until_complete(mycoro())
     assert not loop.is_running()
+
+
+def teardown_module(module):
+    """
+    Remove handlers from all loggers
+    See: https://github.com/pytest-dev/pytest/issues/5502
+    """
+    loggers = [logging.getLogger()] + list(logging.Logger.manager.loggerDict.values())
+    for logger in loggers:
+        handlers = getattr(logger, "handlers", [])
+        for handler in handlers:
+            if isinstance(logger, logging.Logger):
+                logger.removeHandler(handler)
